@@ -63,14 +63,6 @@ class _LDAPConfig(object):
         """
         if cls.ldap is None:
             import ldap.filter
-
-            # Support for python-ldap < 2.0.6
-            try:
-                import ldap.dn
-            except ImportError:
-                from django_auth_ldap import dn
-                ldap.dn = dn
-
             cls.ldap = ldap
 
         # Apply global LDAP options once
@@ -88,12 +80,8 @@ class _LDAPConfig(object):
         Initializes and returns our logger instance.
         """
         if cls.logger is None:
-            class NullHandler(logging.Handler):
-                def emit(self, record):
-                    pass
-
             cls.logger = logging.getLogger('django_auth_ldap')
-            cls.logger.addHandler(NullHandler())
+            cls.logger.addHandler(logging.NullHandler())
 
         return cls.logger
 
@@ -138,7 +126,7 @@ class LDAPSearch(object):
 
         filterstr = '(&{})'.format(''.join(term_strings))
 
-        return self.__class__(self.base_dn, self.scope, filterstr)
+        return self.__class__(self.base_dn, self.scope, filterstr, attrlist=self.attrlist)
 
     def search_with_additional_term_string(self, filterstr):
         """
@@ -148,7 +136,7 @@ class LDAPSearch(object):
         """
         filterstr = '(&{}{})'.format(self.filterstr, filterstr)
 
-        return self.__class__(self.base_dn, self.scope, filterstr)
+        return self.__class__(self.base_dn, self.scope, filterstr, attrlist=self.attrlist)
 
     def execute(self, connection, filterargs=(), escape=True):
         """
